/**************************************************************************************************************************************************
*       USI_I2C.c Set's up the MSP430 uC USI in I2C mode.                                                                                         *
*                                                                                                                                                 *
*       Initiating calls:   main                                                - Called from IAR's reset                                         *
*                                                                                                                                                 *
*       Author:             Mike Claassen                                                                                                         *
*                                                                                                                                                 *
*       Revision Date:      February 2011                                                                                                         *
*                                                                                                                                                 *
*       Revision Level:     1                                                                                                            *
*                                                                                                                                                 *
*                                               *
*                                                                                                                                                 *
*
 * Copyright (C) 2017 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*

***************************************************************************************************************************************************
*                                 MODULE CHANGE LOG                                                                                               *
*                                                                                                                                                 *
*       Date Changed:             {date of change}                Developer:       {developer name}                                               *
*       Change Description:       {describe change}                                                                                               *
*                                                                                                                                                 *
**************************************************************************************************************************************************/
/**************************************************************************************************************************************************
*                                 Included Headers                                                                                                *
**************************************************************************************************************************************************/
#include <msp430x20x3.h>                                                        // Definition Files for the MSP430
/**************************************************************************************************************************************************
*                                 Definitions                                                                                                     *
**************************************************************************************************************************************************/
/************************** I2C SCI Engine ************************************/
#define I2C_SDA 0x80                                                                 // SDA on P1.7
#define I2C_SCL 0x40                                                                 // SCL on P1.6


//   General I2C State Machine
#define I2C_START_CONDITION               0x00
#define I2C_READ_ADDRESS_ACK_NAK          0x01
#define I2C_CHECK_ACK_NAK_ADDRESS         0x02
#define I2C_READ_ACK_NAK_REGISTER         0x03
#define I2C_CHECK_ACK_NAK_REGISTER        0x04
#define I2C_PROCESS_STOP_CONDITION        0x05
#define I2C_STOP_CONDITION                0x06

//  Read State Machine
#define I2C_RESTART_CONDITION             0x10
#define I2C_READ_ACK_NAK_RESTART          0x12
#define I2C_CHECK_ACK_NAK_RESTART         0x14
#define I2C_SEND_ACK_NAK_DATA_READ        0x16
#define I2C_WORD_DATA_READ                0x18

// Write State Machine
#define I2C_READ_ACK_NAK_DATA_WRITE       0x20
#define I2C_CHECK_ACK_NAK_DATA_WRITE      0x22
#define I2C_READ_ACK_NAK_DATA_LSB_WRITE   0x24

#define I2C_WRITE 0x00
#define I2C_READ 0x01

#define I2C_BYTE 0x00
#define I2C_WORD 0x01

#define I2C_ACK  0x00
#define I2C_NAK  0x01
                                                     
/**************************************************************************************************************************************************
*                                 Prototypes                                                                                                      *
**************************************************************************************************************************************************/
/************ System Configuration *************************/
void Set_I2C(void);

/************ I2C Interface *******************************/
unsigned int I2C_Read (unsigned char, unsigned char, unsigned char);
void I2C_Write (unsigned char, unsigned char, unsigned char, unsigned int);
void clear_I2C_State_Machine (void);
void read_ACK_NAK_bit (void);
void transmit_ACK_NAK_bit (unsigned char);
void initiate_I2C_stop (void);
void send_I2C_byte (unsigned char);
void read_I2C_byte (void);

/**************************************************************************************************************************************************
*                                 External Variables                                                                                              *
**************************************************************************************************************************************************/

/**************************************************************************************************************************************************
*                                 Global Variables                                                                                                *
**************************************************************************************************************************************************/

/************ I2C Interface *******************************/
/*unsigned char Read_Write_Mode = I2C_WRITE;                                      // I2C mode used to decide if Repeat Start is needed
unsigned char Byte_Word_Mode = I2C_WORD;                                        // I2C mode used to decide 1 or 2 byte read/write
unsigned int  MST_Data = 0x00;                                                  // Variable for transmitted data
unsigned char SLV_Addr = 0x00;                                                  // I2C Address of Device
unsigned char REG_Addr = 0x00;                                                  // Address in the device being set/read
unsigned int  I2C_State = 0x00;                                                 // State variable
unsigned char I2C_State_Table [14];                                             // Used to troublehoot the I2C state machine
*/
