/**************************************************************************************************************************************************
*  main.c - Main routine containing initializations, background tasks, and ISR functions                                                    	  *
*                                                                                                                                                 *
*               Author: M. Knapp                                                                                                        	      *
*                                                                                                                                                 *
*        Revision Date: April 19, 2017                                                                                                            *
*                                                                                                                                                 *
*       Revision Level: 1.0                                                                                           	                          *
*                                                                                                                                                 *
*                                                                           											                          *
*                                                                                                                                                 *
*                                                                                                                                                 *
***************************************************************************************************************************************************
*  Copyright  2017 Texas Instruments Incorporated - http://www.ti.com/                                                             	      *
***************************************************************************************************************************************************
*  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: *
*                                                                                                                                                 *
*    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.                 *
*                                                                                                                                                 *
*    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the        *
*    documentation and/or other materials provided with the distribution.                                                                         *
*                                                                                                                                                 *
*    Neither the name of Texas Instruments Incorporated nor the names of its contributors may be used to endorse or promote products derived      *
*    from this software without specific prior written permission.                                                                                *
*                                                                                                                                                 *
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          *
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT     *
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT         *
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY    *
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE      *
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.                                                                           *
**************************************************************************************************************************************************/


//******************************************************************************
//  TIDA-00743_Software_1.0 
//  Description: This software is used to configure the TIDA-00743 Module  
//  The software configures the PCM1865 and the TAS6424 
//  to provide an amplified audio output when an audio input is provided.
//
//******************************************************************************

#include <msp430.h>
#include "USI_I2C.h"

//NOTE: Address needs to be in 7 bit form to be used with the current write and read functions.

unsigned char PCM1_Addr = 0x4a;						//PCM1865 Address
unsigned char TAS1_Addr = 0x6a;						//TAS6424 Address

int main(void)
{
  volatile unsigned int i;                  // Use volatile to prevent removal

  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog
  if (CALBC1_1MHZ==0xFF)					// If calibration constant erased
  {
    while(1);                               // do not load, trap CPU!!
  }
  DCOCTL = 0;                               // Select lowest DCOx and MODx settings
  BCSCTL1 = CALBC1_1MHZ;                    // Set DCO
  DCOCTL = CALDCO_1MHZ;

  P1OUT = 0xC0;                             // P1.6 & P1.7 Pullups, others to 0
  P1REN |= 0xC0;                            // P1.6 & P1.7 Pullups
  P1DIR = 0xFF;                             // Unused pins as outputs
  P2OUT = 0x0C;								//Make Sure FS = P2.2 is HIGH so that CDCS503 multiplies by 4. P2.3 = high so TAS is not in STDBY in TIDA00743
  P2DIR = 0xFC;                             //P2.0 and 2.1 inputs

  __delay_cycles(10000);

  Set_I2C();

  __delay_cycles(10000);


//PCM1865 section
  I2C_Write (I2C_BYTE, PCM1_Addr, 0x26, 0x03); //Set BCLK Divider from SCK to 1/4 on PCM1865 - 96 kHz for LR CLK
  I2C_Write (I2C_BYTE, PCM1_Addr, 0x10, 0x51); // Set GPIO1 as DOUT2 on PCM1865
  I2C_Write (I2C_BYTE, PCM1_Addr, 0x20, 0x91); // Set as timing master on PCM1865


  //TAS6424 section
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x00, 0x80); //Master Reset TAS6424.
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x04, 0x55); // Mute outputs on TAS6424

  I2C_Write (I2C_BYTE, TAS1_Addr, 0x00, 0x80); //Master Reset TAS6424.
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x21, 0x80); //Clear Clock Fault

  I2C_Write (I2C_BYTE, TAS1_Addr, 0x01, 0x31); // Set Gain to Level 2 (15V) on TAS6424 1

  I2C_Write (I2C_BYTE, TAS1_Addr, 0x02, 0x62); // Set PWM for 44x FS on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x03, 0x84); // Set Sampling Rate to 96 kHz on TAS6424
  __delay_cycles(100000);
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x05, 0x0f); // Turn down Channel 1 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x06, 0x0f); // Turn down Channel 2 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x07, 0x0f); // Turn down Channel 3 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x08, 0x0f); // Turn down Channel 4 on TAS6424
  __delay_cycles(1000000); // Anti-pop delay
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x04, 0x00); // Un-mute outputs on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x05, 0xd1); // Turn Up Channel 1 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x06, 0xd1); // Turn Up Channel 2 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x07, 0xd1); // Turn Up Channel 3 on TAS6424
  I2C_Write (I2C_BYTE, TAS1_Addr, 0x08, 0xd1); // Turn Up Channel 4 on TAS6424



// }

	  LPM0;
}


